==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Notification Template</source>
        <translation>Шаблон уведомления</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="373"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="402"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Delay (ms):</source>
        <translation>Задежка (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="281"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="334"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="308"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="301"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="108"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="110"/>
        <source>Track number</source>
        <translation>Номер трека</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="111"/>
        <source>Two-digit track number</source>
        <translation>2- разрядный номер трека</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="112"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>Комментрий</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Disc number</source>
        <translation>Номер диска</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>File path</source>
        <translation>Путь к файлу</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Year</source>
        <translation>Год</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="120"/>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="31"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="116"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Notification Template</source>
        <translation>Шаблон уведомления</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Задежка (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="219"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="241"/>
        <source>Edit template</source>
        <translation>Редактировать шаблон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Уведомлять о продолжении воспроизведения</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>
